@@ -1,2 +1,2 @@
 from .reverse_shell import reverse_shell
-from .tools import read_wordlist
+from .tools import *
